@@ -56,6 +56,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_iam
@@ -111,9 +113,9 @@ class CfnProfilingGroup(
         *,
         profiling_group_name: builtins.str,
         agent_permissions: typing.Any = None,
-        anomaly_detection_notification_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnProfilingGroup.ChannelProperty"]]]] = None,
+        anomaly_detection_notification_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, typing.Union["CfnProfilingGroup.ChannelProperty", typing.Dict[str, typing.Any]]]]]] = None,
         compute_platform: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[aws_cdk.core.CfnTag]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''Create a new ``AWS::CodeGuruProfiler::ProfilingGroup``.
 
@@ -125,6 +127,10 @@ class CfnProfilingGroup(
         :param compute_platform: The compute platform of the profiling group. Use ``AWSLambda`` if your application runs on AWS Lambda. Use ``Default`` if your application runs on a compute platform that is not AWS Lambda , such an Amazon EC2 instance, an on-premises server, or a different platform. If not specified, ``Default`` is used. This property is immutable.
         :param tags: A list of tags to add to the created profiling group.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnProfilingGroup.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnProfilingGroupProps(
             profiling_group_name=profiling_group_name,
             agent_permissions=agent_permissions,
@@ -141,6 +147,9 @@ class CfnProfilingGroup(
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnProfilingGroup.inspect)
+            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
@@ -151,6 +160,9 @@ class CfnProfilingGroup(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnProfilingGroup._render_properties)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
     @jsii.python.classproperty # type: ignore[misc]
@@ -199,6 +211,9 @@ class CfnProfilingGroup(
 
     @agent_permissions.setter
     def agent_permissions(self, value: typing.Any) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnProfilingGroup, "agent_permissions").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "agentPermissions", value)
 
     @builtins.property # type: ignore[misc]
@@ -212,6 +227,9 @@ class CfnProfilingGroup(
 
     @profiling_group_name.setter
     def profiling_group_name(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnProfilingGroup, "profiling_group_name").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "profilingGroupName", value)
 
     @builtins.property # type: ignore[misc]
@@ -230,6 +248,9 @@ class CfnProfilingGroup(
         self,
         value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnProfilingGroup.ChannelProperty"]]]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnProfilingGroup, "anomaly_detection_notification_configuration").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "anomalyDetectionNotificationConfiguration", value)
 
     @builtins.property # type: ignore[misc]
@@ -245,6 +266,9 @@ class CfnProfilingGroup(
 
     @compute_platform.setter
     def compute_platform(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnProfilingGroup, "compute_platform").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "computePlatform", value)
 
     @jsii.data_type(
@@ -282,6 +306,10 @@ class CfnProfilingGroup(
                     channel_id="channelId"
                 )
             '''
+            if __debug__:
+                type_hints = typing.get_type_hints(CfnProfilingGroup.ChannelProperty.__init__)
+                check_type(argname="argument channel_uri", value=channel_uri, expected_type=type_hints["channel_uri"])
+                check_type(argname="argument channel_id", value=channel_id, expected_type=type_hints["channel_id"])
             self._values: typing.Dict[str, typing.Any] = {
                 "channel_uri": channel_uri,
             }
@@ -336,9 +364,9 @@ class CfnProfilingGroupProps:
         *,
         profiling_group_name: builtins.str,
         agent_permissions: typing.Any = None,
-        anomaly_detection_notification_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, CfnProfilingGroup.ChannelProperty]]]] = None,
+        anomaly_detection_notification_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[str, typing.Any]]]]]] = None,
         compute_platform: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[aws_cdk.core.CfnTag]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''Properties for defining a ``CfnProfilingGroup``.
 
@@ -377,6 +405,13 @@ class CfnProfilingGroupProps:
                 )]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnProfilingGroupProps.__init__)
+            check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
+            check_type(argname="argument agent_permissions", value=agent_permissions, expected_type=type_hints["agent_permissions"])
+            check_type(argname="argument anomaly_detection_notification_configuration", value=anomaly_detection_notification_configuration, expected_type=type_hints["anomaly_detection_notification_configuration"])
+            check_type(argname="argument compute_platform", value=compute_platform, expected_type=type_hints["compute_platform"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
         self._values: typing.Dict[str, typing.Any] = {
             "profiling_group_name": profiling_group_name,
         }
@@ -549,6 +584,9 @@ class _IProfilingGroupProxy(
 
         :param grantee: Principal to grant publish rights to.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(IProfilingGroup.grant_publish)
+            check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantPublish", [grantee]))
 
     @jsii.member(jsii_name="grantRead")
@@ -562,6 +600,9 @@ class _IProfilingGroupProxy(
 
         :param grantee: Principal to grant read rights to.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(IProfilingGroup.grant_read)
+            check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantRead", [grantee]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -603,6 +644,10 @@ class ProfilingGroup(
         :param compute_platform: The compute platform of the profiling group. Default: ComputePlatform.DEFAULT
         :param profiling_group_name: A name for the profiling group. Default: - automatically generated name.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ProfilingGroup.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ProfilingGroupProps(
             compute_platform=compute_platform,
             profiling_group_name=profiling_group_name,
@@ -624,6 +669,11 @@ class ProfilingGroup(
         :param id: The construct's name.
         :param profiling_group_arn: Profiling Group ARN.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ProfilingGroup.from_profiling_group_arn)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument profiling_group_arn", value=profiling_group_arn, expected_type=type_hints["profiling_group_arn"])
         return typing.cast(IProfilingGroup, jsii.sinvoke(cls, "fromProfilingGroupArn", [scope, id, profiling_group_arn]))
 
     @jsii.member(jsii_name="fromProfilingGroupName") # type: ignore[misc]
@@ -640,6 +690,11 @@ class ProfilingGroup(
         :param id: The construct's name.
         :param profiling_group_name: Profiling Group Name.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ProfilingGroup.from_profiling_group_name)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
         return typing.cast(IProfilingGroup, jsii.sinvoke(cls, "fromProfilingGroupName", [scope, id, profiling_group_name]))
 
     @jsii.member(jsii_name="grantPublish")
@@ -656,6 +711,9 @@ class ProfilingGroup(
 
         :param grantee: Principal to grant publish rights to.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ProfilingGroup.grant_publish)
+            check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantPublish", [grantee]))
 
     @jsii.member(jsii_name="grantRead")
@@ -669,6 +727,9 @@ class ProfilingGroup(
 
         :param grantee: Principal to grant read rights to.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ProfilingGroup.grant_read)
+            check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantRead", [grantee]))
 
     @builtins.property # type: ignore[misc]
@@ -718,6 +779,10 @@ class ProfilingGroupProps:
                 compute_platform=codeguruprofiler.ComputePlatform.AWS_LAMBDA
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ProfilingGroupProps.__init__)
+            check_type(argname="argument compute_platform", value=compute_platform, expected_type=type_hints["compute_platform"])
+            check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
         self._values: typing.Dict[str, typing.Any] = {}
         if compute_platform is not None:
             self._values["compute_platform"] = compute_platform
